package com.cultural.heritage.controller.good;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cultural.heritage.common.BaseResponse;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.common.ResultUtils;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.model.dto.CommonRequest;
import com.cultural.heritage.model.dto.coupon.CouponAddRequest;
import com.cultural.heritage.model.dto.coupon.CouponQueryRequest;
import com.cultural.heritage.model.dto.coupon.CouponUpdateRequest;
import com.cultural.heritage.model.entity.Coupon;
import com.cultural.heritage.service.good.CouponService;
import com.cultural.heritage.service.user.UserService;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.*;

import javax.xml.transform.Result;
import java.util.List;


@RestController
@RequestMapping("/coupon")
@Slf4j
@Tag(name = "优惠券接口")
public class CouponController {

    @Resource
    private CouponService couponService;


    @Resource
    private UserService userService;


    /**
     * 添加优惠券
     * @param couponAddRequest  优惠券添加请求体
     * @return  是否添加成功
     */
    @PostMapping("/add")
    public BaseResponse<Boolean> addCoupon(@RequestBody CouponAddRequest couponAddRequest) {
        if (couponAddRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Coupon coupon = new Coupon();
        BeanUtils.copyProperties(couponAddRequest, coupon);
        boolean result = couponService.save(coupon);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }



    /**
     * 更新优惠券
     * @param couponUpdateRequest   优惠券更新请求体
     * @return  是否更新成功
     */
    @PostMapping("/update")
    public BaseResponse<Boolean> updateCoupon(@RequestBody CouponUpdateRequest couponUpdateRequest) {
        if (couponUpdateRequest == null || couponUpdateRequest.getId() <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Coupon coupon = new Coupon();
        BeanUtils.copyProperties(couponUpdateRequest, coupon);
        boolean result = couponService.updateById(coupon);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }



    /**
     * 删除优惠券
     * @param couponDeleteRequest   优惠券删除请求体
     * @return  是否删除成功
     */
    @PostMapping("/delete")
    public BaseResponse<Boolean> deleteCoupon(@RequestBody CommonRequest couponDeleteRequest) {
        if (couponDeleteRequest == null || couponDeleteRequest.getId() <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Long id = couponDeleteRequest.getId();
        boolean result = couponService.removeById(id);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true);
    }



    /**
     * 查询优惠券列表
     * @param couponQueryRequest 优惠券查询请求体
     * @return 优惠券列表
     */
    @PostMapping("/list/page")
    public BaseResponse<Page<Coupon>> listCouponVOByPage(@RequestBody CouponQueryRequest couponQueryRequest) {
        if (couponQueryRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        long current = couponQueryRequest.getCurrent();
        long pageSize = couponQueryRequest.getPageSize();
        Page<Coupon> page = couponService.page(new Page<>(current, pageSize),
                couponService.getQueryWrapper(couponQueryRequest));
        return ResultUtils.success(page);
    }






}
